@@ -1,5 +1,6 @@
 from dataclasses import dataclass
 from enum import Enum
+from typing import List
 
 import pandas as pd
 from dataclasses_json import LetterCase, dataclass_json
@@ -35,7 +36,7 @@ class CallbackPerformance:
 
 @dataclass
 class CallbackDetails:
-    performance: list[CallbackPerformance]
+    performance: List[CallbackPerformance]
 
 
 @dataclass_json(letter_case=LetterCase.CAMEL)
